@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
    Copyright (C) 2005 Steven L. Scott
 
@@ -13,51 +14,48 @@
 
    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
+   USA
  */
 
 #ifndef POISSON_REGRESSION_MODEL_HPP
 #define POISSON_REGRESSION_MODEL_HPP
 
-#include <Models/Glm/Glm.hpp>
-#include <Models/Glm/PoissonRegressionData.hpp>
-#include <Models/Policies/ParamPolicy_1.hpp>
-#include <Models/Policies/IID_DataPolicy.hpp>
-#include <Models/Policies/PriorPolicy.hpp>
-#include <Models/ModelTypes.hpp>
+#include "Models/Glm/Glm.hpp"
+#include "Models/Glm/PoissonRegressionData.hpp"
+#include "Models/ModelTypes.hpp"
+#include "Models/Policies/IID_DataPolicy.hpp"
+#include "Models/Policies/ParamPolicy_1.hpp"
+#include "Models/Policies/PriorPolicy.hpp"
 
 namespace BOOM {
 
   // A PoissonRegressionModel describes a non-negative integer
   // response y ~ Poisson(E exp(beta*x)), where E is an exposure.
-  class PoissonRegressionModel
-      : public GlmModel,
-        public NumOptModel,
-        virtual public MixtureComponent,
-        public ParamPolicy_1<GlmCoefs>,
-        public IID_DataPolicy<PoissonRegressionData>,
-        public PriorPolicy
-  {
+  class PoissonRegressionModel : public GlmModel,
+                                 public NumOptModel,
+                                 virtual public MixtureComponent,
+                                 public ParamPolicy_1<GlmCoefs>,
+                                 public IID_DataPolicy<PoissonRegressionData>,
+                                 public PriorPolicy {
    public:
-    PoissonRegressionModel(int xdim);
-    PoissonRegressionModel(const Vector& beta);
+    explicit PoissonRegressionModel(int xdim);
+    explicit PoissonRegressionModel(const Vector &beta);
 
     // Use this constructor if the model is supposed to share its
     // coefficient parameter with another model.
-    PoissonRegressionModel(Ptr<GlmCoefs> beta);
+    explicit PoissonRegressionModel(const Ptr<GlmCoefs> &beta);
 
-     PoissonRegressionModel * clone() const override;
+    PoissonRegressionModel *clone() const override;
 
-    GlmCoefs & coef() override;
-    const GlmCoefs & coef()const override;
+    GlmCoefs &coef() override;
+    const GlmCoefs &coef() const override;
     Ptr<GlmCoefs> coef_prm() override;
-    const Ptr<GlmCoefs> coef_prm()const override;
+    const Ptr<GlmCoefs> coef_prm() const override;
 
     // The dimension of the arguments to Loglike and log_likelihood is
     // the number of included coefficients.
-    double Loglike(const Vector &beta,
-                   Vector &g,
-                   Matrix &h,
+    double Loglike(const Vector &beta, Vector &g, Matrix &h,
                    uint nd) const override;
 
     double log_likelihood() const override {
@@ -84,17 +82,17 @@ namespace BOOM {
     //
     // Returns:
     //   The value of log likelihood at the supplied beta.
-    double log_likelihood(const Vector &beta,
-                          Vector *gradient = nullptr,
+    double log_likelihood(const Vector &beta, Vector *gradient = nullptr,
                           Matrix *hessian = nullptr,
                           bool reset_derivatives = true) const;
     // mle() optimizes over the set of included coefficients.
     void mle() override;
 
-    double pdf(const Data *, bool logscale)const override;
-    double logp(const PoissonRegressionData &data)const;
+    double pdf(const Data *, bool logscale) const override;
+    double logp(const PoissonRegressionData &data) const;
+    int number_of_observations() const override { return dat().size(); }
   };
 
-} // namespace BOOM
+}  // namespace BOOM
 
-#endif // POISSON_REGRESSION_MODEL_HPP
+#endif  // POISSON_REGRESSION_MODEL_HPP
