@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2009 Steven L. Scott
 
@@ -19,48 +20,42 @@
 #ifndef BOOM_ABSORBING_MARKOV_CONJUGATE_SAMPLER_HPP
 #define BOOM_ABSORBING_MARKOV_CONJUGATE_SAMPLER_HPP
 
-#include <Models/MarkovModel.hpp>
-#include <Models/PosteriorSamplers/MarkovConjSampler.hpp>
-#include <LinAlg/Selector.hpp>
+#include "LinAlg/Selector.hpp"
+#include "Models/MarkovModel.hpp"
+#include "Models/PosteriorSamplers/MarkovConjSampler.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-  class AbsorbingMarkovConjSampler
-    : public MarkovConjSampler
-  {
-  public:
-    AbsorbingMarkovConjSampler(MarkovModel * Mod,
-                               Ptr<ProductDirichletModel> Q,
-                               Ptr<DirichletModel> pi0,
-                               std::vector<uint> absorbing_states,
+  class AbsorbingMarkovConjSampler : public MarkovConjSampler {
+   public:
+    AbsorbingMarkovConjSampler(MarkovModel *Mod,
+                               const Ptr<ProductDirichletModel> &Q,
+                               const Ptr<DirichletModel> &pi0,
+                               const std::vector<uint> &absorbing_states,
                                RNG &seeding_rng = GlobalRng::rng);
-    AbsorbingMarkovConjSampler(MarkovModel * Mod,
-                               Ptr<ProductDirichletModel> Q,
-                               std::vector<uint> absorbing_states,
+    AbsorbingMarkovConjSampler(MarkovModel *Mod,
+                               const Ptr<ProductDirichletModel> &Q,
+                               const std::vector<uint> &absorbing_states,
                                RNG &seeding_rng = GlobalRng::rng);
-    AbsorbingMarkovConjSampler(MarkovModel * Mod,
-                               const Matrix & Nu,
-                               std::vector<uint> absorbing_states,
+    AbsorbingMarkovConjSampler(MarkovModel *Mod, const Matrix &Nu,
+                               const std::vector<uint> &absorbing_states,
                                RNG &seeding_rng = GlobalRng::rng);
-    AbsorbingMarkovConjSampler(MarkovModel * Mod,
-                               const Matrix & Nu,
-                               const Vector & nu,
-                               std::vector<uint> absorbing_states,
+    AbsorbingMarkovConjSampler(MarkovModel *Mod, const Matrix &Nu,
+                               const Vector &nu,
+                               const std::vector<uint> &absorbing_states,
                                RNG &seeding_rng = GlobalRng::rng);
 
     double logpri() const override;
     void draw() override;
     void find_posterior_mode(double epsilon = 1e-5) override;
-    bool can_find_posterior_mode() const override {
-      return true;
-    }
+    bool can_find_posterior_mode() const override { return true; }
 
-  private:
-    MarkovModel * mod_;
+   private:
+    MarkovModel *mod_;
     Selector abs_;
     Selector trans_;
   };
 
 }  // namespace BOOM
 
-#endif// BOOM_ABSORBING_MARKOV_CONJUGATE_SAMPLER_HPP
+#endif  // BOOM_ABSORBING_MARKOV_CONJUGATE_SAMPLER_HPP
