@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2010 Steven L. Scott
 
@@ -17,37 +18,35 @@
 */
 #ifndef BOOM_SEP_STRAT_SAMPLER_HPP_
 #define BOOM_SEP_STRAT_SAMPLER_HPP_
-#include <Models/MvnModel.hpp>
-#include <Models/GammaModel.hpp>
-#include <Models/PosteriorSamplers/PosteriorSampler.hpp>
-#include <LinAlg/Cholesky.hpp>
+#include "LinAlg/Cholesky.hpp"
+#include "Models/GammaModel.hpp"
+#include "Models/MvnModel.hpp"
+#include "Models/PosteriorSamplers/PosteriorSampler.hpp"
 
-namespace BOOM{
+namespace BOOM {
 
-  class SepStratSampler : public PosteriorSampler{
+  class SepStratSampler : public PosteriorSampler {
    public:
-    SepStratSampler(MvnModel *mod,
-                    const std::vector<Ptr<GammaModel> > & ivar,
+    SepStratSampler(MvnModel *mod, const std::vector<Ptr<GammaModel> > &ivar,
                     RNG &seeding_rng = GlobalRng::rng);
-    SepStratSampler(MvnModel *mod,
-                    Ptr<CorrelationModel> Rprior,
-                    const std::vector<Ptr<GammaModel> > & ivar,
+    SepStratSampler(MvnModel *mod, const Ptr<CorrelationModel> &Rprior,
+                    const std::vector<Ptr<GammaModel> > &ivar,
                     RNG &seeding_rng = GlobalRng::rng);
     void draw() override;
-    double logpri()const override;
+    double logpri() const override;
 
     void set_max_tries(int);
     void set_polar_frac(double);
     void set_alpha(double);
 
-    int nfast()const{ return fast_count_; }
-    int nstable()const{ return stable_count_; }
-    int npolar()const{ return polar_count_; }
+    int nfast() const { return fast_count_; }
+    int nstable() const { return stable_count_; }
+    int npolar() const { return polar_count_; }
 
-    double fast_seconds()const{return fast_time_;}
-    double stable_seconds()const{return stable_time_;}
-    double wasted_seconds()const{return wasted_time_;}
-    double polar_seconds()const{return polar_time_;}
+    double fast_seconds() const { return fast_time_; }
+    double stable_seconds() const { return stable_time_; }
+    double wasted_seconds() const { return wasted_time_; }
+    double polar_seconds() const { return polar_time_; }
     SpdMatrix Sigma();
 
    private:
@@ -65,8 +64,8 @@ namespace BOOM{
     double logp_slice_R(double r);
     double logp_slice_ivar(double ivar);
     void find_limits();
-    double logp0(const SpdMatrix & Sigma, double alpha)const;
-    double logprior(const SpdMatrix & Sigma)const;
+    double logp0(const SpdMatrix &Sigma, double alpha) const;
+    double logprior(const SpdMatrix &Sigma) const;
     double detR(double r);
 
     // fundamental data
@@ -79,8 +78,8 @@ namespace BOOM{
     double n_;
     SpdMatrix sumsq_;
     Matrix sumsq_upper_chol_;
-    mutable SpdMatrix R_;   // workspace for fast_draw.  state for stable_draw
-    mutable Vector sd_;  // workspace for fast_draw.  state for stable_draw
+    mutable CorrelationMatrix R_;  // workspace for fast_draw.  state for stable_draw
+    mutable Vector sd_;    // workspace for fast_draw.  state for stable_draw
 
     int fast_count_;
     int stable_count_;
@@ -103,5 +102,5 @@ namespace BOOM{
     SpdMatrix Rinv_;
   };
 
-}
-#endif// BOOM_SEP_STRAT_SAMPLER_HPP_
+}  // namespace BOOM
+#endif  // BOOM_SEP_STRAT_SAMPLER_HPP_
