@@ -20,15 +20,40 @@
 #ifndef BOOM_DISTRIBUTIONS_RNG_HPP
 #define BOOM_DISTRIBUTIONS_RNG_HPP
 
-#include <boost/random/ranlux.hpp>
+#include <random>
 
 namespace BOOM {
-  typedef boost::random::ranlux64_base_01 RNG;
+  // A random number generator for simulating real valued U[0, 1) deviates.
+  class RNG {
+   public:
+    // Seed with std::random_device.
+    RNG();
 
+    // Seed with a specified value.
+    explicit RNG(long seed);
+
+    // Seed from a C++ standard random device, if one is present.
+    void seed();
+
+    // Seed using a specified value.
+    void seed(long seed) {generator_.seed(seed);}
+
+    // Simulate a U[0, 1) random deviate.
+    double operator()() {return dist_(generator_);}
+
+    std::mt19937_64 & generator() {return generator_;}
+    
+   private:
+    // TODO(steve): once you can use c++17 in R and elsewhere replace this with
+    // a std::variant that will choose the fastest RNG for each implementation.
+    std::mt19937_64 generator_;
+    std::uniform_real_distribution<double> dist_;
+  };
+
+  // The GlobalRng is a singleton.
   struct GlobalRng {
    public:
     static RNG rng;
-    static void seed_with_timestamp();
   };
 
   unsigned long seed_rng();  // generates a random seed from the global RNG
