@@ -19,7 +19,7 @@
 #ifndef BOOM_RINTERFACE_CREATE_POISSON_PROCESS_HPP_
 #define BOOM_RINTERFACE_CREATE_POISSON_PROCESS_HPP_
 
-#include <r_interface/list_io.hpp>
+#include "r_interface/list_io.hpp"
 #include "Models/PointProcess/PoissonProcess.hpp"
 
 namespace BOOM{
