@@ -43,7 +43,7 @@ pnbeta_raw(double x, double o_x, double a, double b, double ncp)
 
     /* change errmax and itrmax if desired;
      * original (AS 226, R84) had  (errmax; itrmax) = (1e-6; 100) */
-    const static double errmax = 1.0e-9;
+    constexpr double errmax = 1.0e-9;
     const int    itrmax = 10000;  /* 100 is not enough for pf(ncp=200)
                                      see PR#11277 */
 
