@@ -1,3 +1,4 @@
+// Copyright 2018 Google LLC. All Rights Reserved.
 /*
   Copyright (C) 2005-2011 Steven L. Scott
 
@@ -15,37 +16,31 @@
   License along with this library; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
-#include <Models/Glm/PosteriorSamplers/AggregatedRegressionSampler.hpp>
-#include <Models/Glm/PosteriorSamplers/BregVsSampler.hpp>
-namespace BOOM{
+#include "Models/Glm/PosteriorSamplers/AggregatedRegressionSampler.hpp"
+#include "Models/Glm/PosteriorSamplers/BregVsSampler.hpp"
+namespace BOOM {
 
   namespace {
     inline void check_positive(double value, const char *name) {
-      if(!(value > 0)) {
+      if (!(value > 0)) {
         ostringstream err;
         err << name << " was " << value << " (must be postive) " << endl;
         report_error(err.str());
       }
     }
-  }
+  }  // namespace
 
   AggregatedRegressionSampler::AggregatedRegressionSampler(
-      AggregatedRegressionModel *model,
-      double prior_sigma_nobs,
-      double prior_sigma_guess,
-      double prior_beta_nobs,
+      AggregatedRegressionModel *model, double prior_sigma_nobs,
+      double prior_sigma_guess, double prior_beta_nobs,
       double prior_diagonal_shrinkage,
-      double prior_variable_inclusion_probability,
-      RNG &seeding_rng)
+      double prior_variable_inclusion_probability, RNG &seeding_rng)
       : PosteriorSampler(seeding_rng),
         model_(model),
-        sam_(new BregVsSampler(model_->regression_model(),
-                               prior_sigma_nobs,
-                               prior_sigma_guess,
-                               prior_beta_nobs,
+        sam_(new BregVsSampler(model_->regression_model(), prior_sigma_nobs,
+                               prior_sigma_guess, prior_beta_nobs,
                                prior_diagonal_shrinkage,
-                               prior_variable_inclusion_probability))
-  {
+                               prior_variable_inclusion_probability)) {
     check_positive(prior_sigma_guess, "prior_sigma_guess");
     check_positive(prior_sigma_nobs, "prior_sigma_nobs");
     check_positive(prior_beta_nobs, "prior_beta_nobs");
@@ -55,12 +50,10 @@ namespace BOOM{
     model_->set_method(sam_);
   }
 
-  void AggregatedRegressionSampler::draw(){
+  void AggregatedRegressionSampler::draw() {
     model_->distribute_group_totals();
     sam_->draw();
   }
 
-  double AggregatedRegressionSampler::logpri()const{
-    return sam_->logpri();
-  }
-}
+  double AggregatedRegressionSampler::logpri() const { return sam_->logpri(); }
+}  // namespace BOOM
