@@ -20,7 +20,7 @@
 #include <algorithm>
 #include <cstring>
 #include <sstream>
-#include "BOOM.hpp"
+#include "uint.hpp"
 #include "cpputil/math_utils.hpp"
 #include "cpputil/report_error.hpp"
 
